@@ -80,15 +80,7 @@ class Optimizer():
         run_cwd_ = os.getcwd()
 
         def _run_unit():
-            try:
-                submission.run_submission()
-            except Exception as e:
-                print(os.getcwd())
-                if os.path.exists('0/xyz/4do2a5oxwe0w.xyz'):
-                    print('11111111111111111')
-                with open(r'./opt_error.log', 'a') as f:
-                    f.write(str(e) + '\n' + str(self.task_list) + '\n')
-
+            submission.run_submission()
         self.mach = Machine(batch_type=self.mach_para['batch_type'],
                             context_type=self.mach_para['context_type'],
                             remote_root=self.mach_para['remote_root'],
@@ -101,13 +93,11 @@ class Optimizer():
                                queue_name=self.resrc_para['queue_name'],
                                envs=self.resrc_para['envs']
                                )
-        if self.resrc_para['sub_batch_size'] == None:
+        if 'sub_batch_size' not in self.resrc_para.keys() or self.resrc_para['sub_batch_size'] == None:
             submission = Submission(work_base=self.path_cooking,
-                                    machine=mach,
-                                    resources=resrc,
+                                    machine=self.mach,
+                                    resources=self.resrc,
                                     task_list=self.task_list,
-                                    forward_common_files=[],
-                                    backward_common_files=[]
                                     )
             _run_unit()
         else:
