@@ -7,38 +7,32 @@ para = {
     'root': r'./',
     'gen_para': {'group': 'Cl',
                  'geom_mode': 'pre_defined',
-                 'gen_core_path': r'I:\new_nauty\my_v\usenauty\bin\cagesearch.exe'
+                 'gen_core_path': r'xx/bin/cagesearch.exe'
                  },
     'opt_mode': 'xtb',
     'opt_para': {
-        'cmd_list': [r'/home/mkliu/anaconda3/envs/env001/bin/xtb', '--opt', 'tight', '--json'],
+        'cmd_list': [r'xx/bin/xtb', '--opt', 'tight', '--json'],
         'out_list': ['xtbopt.xyz', 'xtbopt.log', 'xtbout.json'],
         'deal_wrong_mode': 'Report',
         'mach_para': {
-            'batch_type': "Torque",
+            'batch_type': "x",
             'context_type': "SSHContext",
-            'remote_root': '/home/mkliu/test_dpdispatcher/',
+            'remote_root': 'xx/',
             'remote_profile': {
-                "hostname": "219.245.39.76",
-                "username": "mkliu",
-                "password": "mkliu123",
+                "hostname": "xx",
+                "username": "xx",
+                "password": "xx",
                 "port": 22,
                 "timeout": 10
             }
         },
         'resrc_para': {
-            'number_node': 1,
+            'number_node': 6,
             'cpu_per_node': 6,
             'gpu_per_node': 0,
-            'group_size': 3,
+            'group_size': 10,
             'queue_name': "batch",
-            'envs': {
-                "OMP_STACKSIZE": "4G",
-                "OMP_NUM_THREADS": "3,1",
-                "OMP_MAX_ACTIVE_LEVELS": "1",
-                "MKL_NUM_THREADS": "3"
-            },
-            'sub_batch_size': 64
+            'sub_batch_size': 50
         },
     },
 
